@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -1533,12 +1533,19 @@ Track* Composition::getTrackById(TrackId track) const
 	      << __FILE__ << ":" << __LINE__ << std::endl;
     std::cerr << "Available track ids are: " << std::endl;
     for (trackconstiterator i = m_tracks.begin(); i != m_tracks.end(); ++i) {
-	std::cerr << (*i).second->getId() << std::endl;
+	std::cerr << (int)(*i).second->getId() << std::endl;
     }
 
     return 0;
 }
 
+bool
+Composition::haveTrack(TrackId track) const
+{
+    trackconstiterator i = m_tracks.find(track);
+    return (i != m_tracks.end());
+}
+
 // Move a track object to a new id and position in the container -
 // used when deleting and undoing deletion of tracks.
 //
@@ -1653,6 +1660,7 @@ bool Composition::detachTrack(Rosegarden::Track *track)
     m_tracks.erase(it);
     updateRefreshStatuses();
     checkSelectedAndRecordTracks();
+    notifyTrackDeleted(track->getId());
 
     return true;
 }
