@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -38,9 +38,9 @@ class EventSelection;
 class ChangeVelocityCommand : public BasicSelectionCommand
 {
 public:
-    ChangeVelocityCommand(int delta, EventSelection &selection) :
+    ChangeVelocityCommand(int delta, EventSelection &selection,bool rounddelta=true) :
         BasicSelectionCommand(getGlobalName(delta), selection, true),
-        m_selection(&selection), m_delta(delta) { }
+        m_selection(&selection), m_delta(delta),m_rounddelta(rounddelta) { }
 
     static QString getGlobalName(int delta = 0) {
         if (delta > 0) return i18n("&Increase Velocity");
@@ -53,6 +53,7 @@ protected:
 private:
     EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
     int m_delta;
+    bool m_rounddelta;
 };
 
 
