@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -749,7 +749,7 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
         
 	QString presetLabelStr = atts.value("defaultLabel");
 	if (labelStr) {
-	    track->setPresetLabel(presetLabelStr);
+	    track->setPresetLabel(qstrtostr(presetLabelStr));
 	}	
 	
         QString clefStr = atts.value("defaultClef");
