@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -26,7 +26,6 @@
 #include "base/RealTime.h"
 #include "base/Segment.h"
 #include "base/Studio.h"
-#include "gui/application/RosegardenGUIApp.h"
 #include "gui/editors/segment/segmentcanvas/AudioPreviewThread.h"
 #include <map>
 #include "sound/AudioFileManager.h"
@@ -198,6 +197,7 @@ public:
      * empty, exports all devices.
      */ 
     bool exportStudio(const QString &filename,
+		      QString &errMsg,
                       std::vector<DeviceId> devices =
                       std::vector<DeviceId>());
 
@@ -417,9 +417,7 @@ public:
 
     // Get the sequence manager from the app
     //
-    SequenceManager* getSequenceManager() 
-        { return (dynamic_cast<RosegardenGUIApp*>(parent()))
-                                         ->getSequenceManager(); }
+    SequenceManager* getSequenceManager();
 
     //Obsolete: multitrack MIDI recording. plcl 06/2006.
     //Segment *getRecordMIDISegment() { return m_recordMIDISegment; }
@@ -604,6 +602,14 @@ protected:
      */
     void insertRecordedEvent(Event *ev, int device, int channel, bool isNoteOn);
 
+    /**
+     * Transpose an entire segment relative to its destination track.  This is
+     * used for transposing a source MIDI recording segment on a per-track
+     * basis, so that the results all come out with the same sound as the
+     * original recording.
+     */
+    void transposeRecordedSegment(Segment *s);
+
     //--------------- Data members ---------------------------------
 
     /**
