@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -72,6 +72,7 @@
 #include "gui/general/GUIPalette.h"
 #include "gui/general/MidiPitchLabel.h"
 #include "gui/kdeext/KTmpStatusMsg.h"
+#include "gui/rulers/ControlRuler.h"
 #include "gui/rulers/ChordNameRuler.h"
 #include "gui/rulers/LoopRuler.h"
 #include "gui/rulers/PercussionPitchRuler.h"
@@ -88,6 +89,7 @@
 #include "MatrixMover.h"
 #include "MatrixPainter.h"
 #include "MatrixResizer.h"
+#include "MatrixVelocity.h"
 #include "MatrixSelector.h"
 #include "MatrixStaff.h"
 #include "MatrixToolBox.h"
@@ -657,6 +659,13 @@ void MatrixView::setupActions()
                                   this, SLOT(slotResizeSelected()),
                                   actionCollection(), "resize");
     toolAction->setExclusiveGroup("tools");
+    
+   QCanvasPixmap velocitypixmap(pixmapDir + "/toolbar/velocity.xpm");
+    toolAction = new KRadioAction(i18n("&Velocity"), QIconSet(velocitypixmap), Key_F7,
+                                  this, SLOT(slotVelocityChangeSelected()),
+                                  actionCollection(), "velocity");
+    toolAction->setExclusiveGroup("tools");
+    
 
     icon = QIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap("chord")));
     (new KToggleAction(i18n("C&hord Insert Mode"), icon, Key_H,
@@ -1108,6 +1117,14 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
     //!!! rather too much here shared with notationview -- could much of
     // this be in editview?
 
+    /// The assignment of event selection to the ruler needs to be first
+    /// otherwise we get some unsafe thread usages that i had hard to solve.
+    ///  Let's leave this alone as is for now...
+    ControlRuler *ruler=EditView::getCurrentControlRuler();
+    if(ruler)
+	ruler->assignEventSelection(s);
+
+	
     if (m_currentEventSelection == s)	{
         updateQuantizeCombo();
         return ;
@@ -1143,8 +1160,7 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
     bool updateRequired = true;
 
     if (s) {
-
-        bool foundNewEvent = false;
+         bool foundNewEvent = false;
 
         for (EventSelection::eventcontainer::iterator i =
                     s->getSegmentEvents().begin();
@@ -1223,19 +1239,20 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
         }
     }
 
-    delete oldSelection;
-
+    
     if (s) {
 
         int eventsSelected = s->getSegmentEvents().size();
         m_selectionCounter->setText
         (i18n("  1 event selected ",
               "  %n events selected ", eventsSelected));
-
+		
     } else {
         m_selectionCounter->setText(i18n("  No selection "));
     }
 
+    delete oldSelection;
+    
     m_selectionCounter->update();
 
     slotSetCurrentVelocityFromSelection();
@@ -1332,6 +1349,13 @@ void MatrixView::slotResizeSelected()
     setTool(resizer);
 }
 
+void MatrixView::slotVelocityChangeSelected()
+{
+    EditTool* velocity = m_toolBox->getTool(MatrixVelocity::ToolName);
+
+    setTool(velocity);
+}
+
 void MatrixView::slotTransformsQuantize()
 {
     if (!m_currentEventSelection)
@@ -1580,6 +1604,11 @@ MatrixView::slotSetInsertCursorPosition(timeT time, bool scroll)
     //!!! For now.  Probably unlike slotSetPointerPosition this one
     // should snap to the nearest event or grid line.
 
+    Segment &s = m_staffs[0]->getSegment();
+
+    if (time < s.getStartTime())     time = s.getStartTime();
+    if (time > s.getEndMarkerTime()) time = s.getEndMarkerTime();
+    
     m_staffs[0]->setInsertCursorPosition(m_hlayout, time);
 
     if (scroll && !getCanvasView()->isAutoScrolling()) {
