@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -49,6 +49,8 @@
 #include <qwidget.h>
 #include <algorithm>
 
+#include <qtooltip.h>
+
 
 namespace Rosegarden
 {
@@ -69,58 +71,74 @@ MIDIInstrumentParameterPanel::MIDIInstrumentParameterPanel(RosegardenGUIDoc *doc
     m_programCheckBox = new QCheckBox(this);
     m_variationCheckBox = new QCheckBox(this);
     m_percussionCheckBox = new QCheckBox(this);
-
+    
     m_bankValue->setSizeLimit(20);
     m_programValue->setSizeLimit(20);
     m_variationValue->setSizeLimit(20);
-
+    
     m_bankLabel = new QLabel(i18n("Bank"), this);
     m_variationLabel = new QLabel(i18n("Variation"), this);
     m_programLabel = new QLabel(i18n("Program"), this);
     QLabel *channelLabel = new QLabel(i18n("Channel out"), this);
     QLabel *percussionLabel = new QLabel(i18n("Percussion"), this);
-
+    
     // Ensure a reasonable amount of space in the program dropdowns even
     // if no instrument initially selected
     QFontMetrics metrics(m_programValue->font());
     int width22 = metrics.width("1234567890123456789012");
     int width25 = metrics.width("1234567890123456789012345");
-
+    
     m_bankValue->setMinimumWidth(width22);
     m_programValue->setMinimumWidth(width22);
     m_variationValue->setMinimumWidth(width22);
-
+    
     m_connectionLabel->setFixedWidth(width25);
     m_connectionLabel->setAlignment(Qt::AlignCenter);
-
+    
+    
+    QString programTip = i18n("<qt>Use program changes from an external source to manipulate these controls (only valid for the currently-active track) [Shift+P]</qt>");
+    m_evalMidiPrgChgCheckBox = new QCheckBox(this); 
+    m_evalMidiPrgChgLabel = new QLabel(i18n("Receive external program changes"), this);
+    QToolTip::add(m_evalMidiPrgChgLabel, programTip);
+    
+    m_evalMidiPrgChgCheckBox->setDisabled(false);
+    m_evalMidiPrgChgCheckBox->setChecked(false);
+    QToolTip::add(m_evalMidiPrgChgCheckBox, programTip);
+    m_evalMidiPrgChgCheckBox->setAccel((QKeySequence)"Shift+P");
+    
+    
     // Configure the empty final row to accomodate any extra vertical space.
-
+    
     m_mainGrid->setRowStretch(m_mainGrid->numRows() - 1, 1);
 
 
     m_mainGrid->setColStretch(2, 1);
 
-    m_mainGrid->addMultiCellWidget(m_instrumentLabel, 0, 0, 0, 2, AlignCenter);
-    m_mainGrid->addMultiCellWidget(m_connectionLabel, 1, 1, 0, 2, AlignCenter);
+    m_mainGrid->addMultiCellWidget(m_instrumentLabel, 0, 0, 0, 3, AlignCenter);
+    m_mainGrid->addMultiCellWidget(m_connectionLabel, 1, 1, 0, 3, AlignCenter);
 
     m_mainGrid->addMultiCellWidget(channelLabel, 2, 2, 0, 1, AlignLeft);
-    m_mainGrid->addWidget(m_channelValue, 2, 2, AlignRight);
+    m_mainGrid->addWidget(m_channelValue, 2, 3, AlignRight);
 
     m_mainGrid->addMultiCellWidget(percussionLabel, 3, 3, 0, 1, AlignLeft);
-    m_mainGrid->addWidget(m_percussionCheckBox, 3, 2, AlignRight);
+    m_mainGrid->addWidget(m_percussionCheckBox, 3, 3, AlignRight);
 
     m_mainGrid->addWidget(m_bankLabel, 4, 0, AlignLeft);
     m_mainGrid->addWidget(m_bankCheckBox, 4, 1, AlignRight);
-    m_mainGrid->addWidget(m_bankValue, 4, 2, AlignRight);
+    m_mainGrid->addMultiCellWidget(m_bankValue, 4, 4, 2, 3, AlignRight);
 
     m_mainGrid->addWidget(m_programLabel, 5, 0, AlignLeft);
     m_mainGrid->addWidget(m_programCheckBox, 5, 1, AlignRight);
-    m_mainGrid->addWidget(m_programValue, 5, 2, AlignRight);
+    m_mainGrid->addMultiCellWidget(m_programValue, 5, 5, 2, 3, AlignRight);
 
     m_mainGrid->addWidget(m_variationLabel, 6, 0);
     m_mainGrid->addWidget(m_variationCheckBox, 6, 1);
-    m_mainGrid->addWidget(m_variationValue, 6, 2, AlignRight);
-
+    m_mainGrid->addMultiCellWidget(m_variationValue, 6, 6, 2, 3, AlignRight);
+      
+    m_mainGrid->addMultiCellWidget(m_evalMidiPrgChgLabel, 7, 7, 0, 2, AlignLeft);
+    m_mainGrid->addWidget(m_evalMidiPrgChgCheckBox, 7, 3, AlignRight);	
+    
+    
     // Populate channel lists
     //
     for (int i = 0; i < 16; i++) {
@@ -156,8 +174,11 @@ MIDIInstrumentParameterPanel::MIDIInstrumentParameterPanel(RosegardenGUIDoc *doc
 
     connect(m_variationCheckBox, SIGNAL(toggled(bool)),
             this, SLOT(slotToggleVariation(bool)));
-
-
+    
+    connect(m_evalMidiPrgChgCheckBox, SIGNAL(toggled(bool)),
+    		this, SLOT(slotToggleChangeListOnProgChange(bool)) );
+    
+    
     // Connect activations
     //
     connect(m_bankValue, SIGNAL(activated(int)),
@@ -182,6 +203,14 @@ MIDIInstrumentParameterPanel::MIDIInstrumentParameterPanel(RosegardenGUIDoc *doc
             this, SLOT(slotControllerChanged(int)));
 }
 
+
+void MIDIInstrumentParameterPanel::slotToggleChangeListOnProgChange(bool val){
+    // used to disable prog-change select-box 
+    // (in MIDIInstrumentParameterPanel), if TrackChanged 
+	this->m_evalMidiPrgChgCheckBox->setChecked(val);
+}
+
+
 void
 MIDIInstrumentParameterPanel::setupForInstrument(Instrument *instrument)
 {
@@ -623,11 +652,15 @@ MIDIInstrumentParameterPanel::populateProgramList()
             m_programLabel->show();
             m_programCheckBox->show();
             m_programValue->show();
+            m_evalMidiPrgChgCheckBox->show();
+            m_evalMidiPrgChgLabel->show();
         }
     } else {
         m_programLabel->hide();
         m_programCheckBox->hide();
         m_programValue->hide();
+        m_evalMidiPrgChgCheckBox->hide();
+        m_evalMidiPrgChgLabel->hide();
     }
 
     for (unsigned int i = 0; i < programs.size(); ++i) {
@@ -945,6 +978,89 @@ MIDIInstrumentParameterPanel::slotSelectBank(int index)
     emit instrumentParametersChanged(m_selectedInstrument->getId());
 }
 
+
+
+
+
+void MIDIInstrumentParameterPanel::slotSelectProgramNoSend(int prog, int bank_lsb, int bank_msb )
+{
+    /*
+     * This function changes the program-list entry, if
+     * a midi program change message occured.
+     * 
+     * (the slot is being connected in RosegardenGUIApp.cpp,
+     *  and called (signaled) by SequenceManger.cpp)
+     * 
+     * parameters:
+     * prog : the program to select (triggered by program change message)
+     * bank_lsb : the bank to select (if no bank-select occured, this is -1)
+     *				(triggered by bank-select message (fine,lsb value))
+     * bank_msb : coarse/msb value  (-1 if not specified)
+     */
+    if( ! this->m_evalMidiPrgChgCheckBox->isChecked() ){
+        return;
+    }
+	
+	
+	
+	
+	if (m_selectedInstrument == 0)
+		return ;
+
+	MidiDevice *md = dynamic_cast<MidiDevice*>
+			(m_selectedInstrument->getDevice());
+	
+	if (!md) {
+		RG_DEBUG << "WARNING: MIDIInstrumentParameterPanel::slotSelectBank: No MidiDevice for Instrument "
+				<< m_selectedInstrument->getId() << endl;
+		return ;
+	}
+	
+	bool changed_bank = false;
+	// bank msb value (MSB, coarse)
+	if ((bank_msb >= 0) ){ // and md->getVariationType() != MidiDevice::VariationFromMSB ) {
+		if (m_selectedInstrument->getMSB() != bank_msb ) {
+			m_selectedInstrument->setMSB( bank_msb );
+			changed_bank = true;
+		}
+	}	
+	// selection of bank (LSB, fine)
+	if ((bank_lsb >= 0) ){ //and md->getVariationType() != MidiDevice::VariationFromLSB) {
+		if (m_selectedInstrument->getLSB() != bank_lsb ) {
+			m_selectedInstrument->setLSB( bank_lsb );
+			changed_bank = true;
+		}
+	}
+	
+    bool change = false;
+	if (m_selectedInstrument->getProgramChange() != (MidiByte)prog) {
+        m_selectedInstrument->setProgramChange( (MidiByte)prog );
+        change = true;
+    }
+    
+    //populateVariationList();
+    
+    if (change or changed_bank) {
+        //sendBankAndProgram();
+        //emit changeInstrumentLabel( m_selectedInstrument->getId(),
+        //            strtoqstr(m_selectedInstrument->getProgramName()) );
+        emit updateAllBoxes();
+        
+        emit instrumentParametersChanged(m_selectedInstrument->getId());
+    }
+    
+}
+
+
+
+
+
+
+
+
+
+
+
 void
 MIDIInstrumentParameterPanel::slotSelectProgram(int index)
 {
