@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -54,12 +54,13 @@ public:
     virtual void setupForInstrument(Instrument*);
 
     void showAdditionalControls(bool showThem);
-
+    
 signals:
     void changeInstrumentLabel(InstrumentId id, QString label);
     void instrumentParametersChanged(InstrumentId);
 
 public slots:
+    void slotSelectProgramNoSend(int prog, int bank_lsb, int bank_msb);
     void slotSelectProgram(int index);
     void slotSelectBank(int index);
     void slotSelectVariation(int index);
@@ -73,6 +74,8 @@ public slots:
     void slotToggleBank(bool value);
     void slotToggleVariation(bool value);
 
+    void slotToggleChangeListOnProgChange(bool val);
+
 protected:
 
     // fill (or hide) bank combo based on whether the instrument is percussion
@@ -107,10 +110,12 @@ protected:
     QCheckBox          *m_bankCheckBox;
     QCheckBox          *m_variationCheckBox;
     QCheckBox          *m_programCheckBox;
+    QCheckBox          *m_evalMidiPrgChgCheckBox;
 
     QLabel             *m_bankLabel;
     QLabel             *m_variationLabel;
     QLabel             *m_programLabel;
+    QLabel             *m_evalMidiPrgChgLabel;
 
     QGridLayout        *m_mainGrid;
     QFrame             *m_rotaryFrame;
