@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -37,6 +37,7 @@
 #include "base/MidiDevice.h"
 #include "base/MidiProgram.h"
 #include "base/MidiTypes.h"
+#include "base/NotationRules.h"
 #include "base/NotationTypes.h"
 #include "base/Profiler.h"
 #include "base/Property.h"
@@ -1198,9 +1199,22 @@ EditView::getPitchFromNoteInsertAction(QString name,
 	//
 	// Note: middle-C is in octave 5 + octaveBase (default = -2) = 3 (hjj)
 	//
-        Pitch pitch
-        (scalePitch, 3 + octave + clef.getOctave(), key, accidental);
-        return pitch.getPerformancePitch();
+	int clefOctave = 3 + octave + clef.getOctave();
+	
+	//
+	// Keep the distance (clef position)-(1st note of scale) between 0...6 
+	//
+	int clefHeightFromC = 2 + clef.getAxisHeight() - clef.getPitchOffset();
+	int firstScaleNoteHeightFromC = ( key.isSharp() ?
+		steps_Cmajor_with_sharps[key.getTonicPitch()] :
+		steps_Cmajor_with_flats[key.getTonicPitch()] );
+
+	int octaveAdjust = clefHeightFromC - firstScaleNoteHeightFromC;
+	octaveAdjust=(octaveAdjust-((77+octaveAdjust)%7))/ 7; // (x-mod(x,7))/7
+	
+	Pitch pitch
+	(scalePitch, clefOctave + octaveAdjust, key, accidental);
+	return pitch.getPerformancePitch();
 
     } else {
 
