@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -63,6 +63,7 @@ ControlRuler::ControlRuler(Segment *segment,
         m_mainHorizontalScrollBar(0),
         m_rulerScale(rulerScale),
         m_eventSelection(new EventSelection(*segment)),
+	m_assignedEventSelection(0),
         m_segment(segment),
         m_currentItem(0),
         m_tool(0),
@@ -75,6 +76,8 @@ ControlRuler::ControlRuler(Segment *segment,
         m_selectionRect(new QCanvasRectangle(canvas())),
         m_menu(0)
 {
+    pthread_mutex_t m_mutex = PTHREAD_MUTEX_INITIALIZER;
+
     setHScrollBarMode(QScrollView::AlwaysOff);
 
     m_selectionRect->setPen(Qt::red);
@@ -94,6 +97,10 @@ ControlRuler::ControlRuler(Segment *segment,
 
 ControlRuler::~ControlRuler()
 {
+    pthread_mutex_destroy( &m_mutex);
+    if(m_assignedEventSelection)
+	    m_assignedEventSelection->removeObserver(this);
+    
     if (m_segment) {
         m_segment->removeObserver(this);
     }
@@ -149,6 +156,80 @@ void ControlRuler::setControlTool(ControlTool* tool)
     m_tool = tool;
 }
 
+void ControlRuler::eventSelected(EventSelection *es,Event *e) {
+    if(es==m_assignedEventSelection) {
+        QCanvasItemList list = canvas()->allItems();
+        QCanvasItemList::Iterator it = list.begin();
+        for (; it != list.end(); ++it) {
+            if (ControlItem *item = dynamic_cast<ControlItem*>(*it)) {
+    		if(item->getElementAdapter()->getEvent()==e) {
+			item->setHighlighted(true);
+			return;
+		}
+	    }
+        }
+    }
+}
+
+void ControlRuler::eventDeselected(EventSelection *es,Event *e) {
+    if(es==m_assignedEventSelection) {
+        QCanvasItemList list = canvas()->allItems();
+        QCanvasItemList::Iterator it = list.begin();
+        for (; it != list.end(); ++it) {
+            if (ControlItem *item = dynamic_cast<ControlItem*>(*it)) {
+	        if(item->getElementAdapter()->getEvent()==e) {
+		    item->setHighlighted(false);
+		    return;
+	        }
+            }
+        }
+    }
+}
+
+void ControlRuler::eventSelectionDestroyed(EventSelection *es) {
+	/// Someone destroyed  ES  lets handle that
+	if(es==m_assignedEventSelection)
+		m_assignedEventSelection=NULL;
+}
+    
+
+void ControlRuler::assignEventSelection(EventSelection *es) 
+{
+    // Clear all selected ControllItem
+    QCanvasItemList list = canvas()->allItems();
+    QCanvasItemList::Iterator it = list.begin();
+    for (; it != list.end(); ++it) {
+        if (ControlItem *item = dynamic_cast<ControlItem*>(*it)) 
+	    item->setHighlighted(false);
+    }		
+
+    if(es) {
+	// Dont observe the old selection anymore
+	m_assignedEventSelection=es;
+
+	QCanvasItemList list = canvas()->allItems();
+        const EventSelection::eventcontainer ec=es->getSegmentEvents();
+        for (EventSelection::eventcontainer::iterator e = ec.begin(); e != ec.end(); ++e) {
+	    QCanvasItemList::Iterator it = list.begin();
+	    for (; it != list.end(); ++it) {
+                if (ControlItem *item = dynamic_cast<ControlItem*>(*it)) {
+    		    if(item->getElementAdapter()->getEvent()==*e) {
+			item->setHighlighted(true);
+			break;
+	    	    }
+	        }
+            }
+        } 
+	
+        es->addObserver(this);
+
+    } else {
+	m_assignedEventSelection=NULL;
+    }
+    
+    slotUpdate();
+}
+
 void
 ControlRuler::segmentDeleted(const Segment *)
 {
