@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -25,11 +25,11 @@ namespace Rosegarden
 ControlRulerEventInsertCommand::ControlRulerEventInsertCommand(const std::string &type,
                                                                timeT insertTime,
                                                                long number, long initialValue,
-                                                               Segment &segment)
+                                                               Segment &segment,timeT duration)
     : BasicCommand(i18n("Insert Controller Event"),
                    segment,
                    insertTime, 
-                   (insertTime + Rosegarden::Note(Rosegarden::Note::Quaver).getDuration())), // must have a duration other undo doesn't work
+                   (duration!=0)?(insertTime+duration):(insertTime + Rosegarden::Note(Rosegarden::Note::Quaver).getDuration())), // must have a duration other undo doesn't work
       m_type(type),
       m_number(number),
       m_initialValue(initialValue)
