@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -31,7 +31,8 @@ public:
                                    timeT insertTime, 
                                    long number, 
                                    long initialValue,
-                                   Segment &segment);
+                                   Segment &segment,
+				    timeT duration=0);
 
     virtual ~ControlRulerEventInsertCommand() {;}
 
