@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2008 the Rosegarden development team.
+    Copyright 2000-2009 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -44,6 +44,7 @@
 #include <klocale.h>
 #include <kaction.h>
 #include <kstddirs.h>
+#include <kmainwindow.h>
 #include <qtooltip.h>
 
 
@@ -194,8 +195,8 @@ MarkerRuler::slotDeleteMarker()
     if (marker)
         emit deleteMarker(marker->getID(),
                           marker->getTime(),
-                          marker->getName(),
-                          marker->getDescription());                          
+                          strtoqstr(marker->getName()),
+                          strtoqstr(marker->getDescription()));                          
 }
 
 void
