@@ -3,7 +3,7 @@
 /*
   Rosegarden
   A sequencer and musical notation editor.
-  Copyright 2000-2008 the Rosegarden development team.
+  Copyright 2000-2009 the Rosegarden development team.
  
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -22,6 +22,10 @@
 #include "BaseProperties.h"
 #include "Midi.h"
 #include "MidiTypes.h"
+#include "NotationTypes.h" // for Note::EventType
+
+#include <cassert>
+#include <cstdlib>
 
 #define DEBUG_MAPPEDEVENT 1
 
@@ -32,7 +36,7 @@ MappedEvent::MappedEvent(InstrumentId id,
                          const Event &e,
                          const RealTime &eventTime,
                          const RealTime &duration):
-        m_trackId(0),
+        m_trackId(NO_TRACK),
         m_instrument(id),
         m_type(MidiNote),
         m_data1(0),
